abacusai.streaming_sample_code — AbacusAI documentation

# abacusai.streaming_sample_code

## Classes

`StreamingSampleCode` | Sample code for adding to a streaming feature group with examples from different locations.

## Module Contents

class abacusai.streaming_sample_code.StreamingSampleCode(client, python=None, curl=None, console=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Sample code for adding to a streaming feature group with examples from different locations.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - python (str) – The python code sample.

    - curl (str) – The curl code sample.

    - console (str) – The console code sample

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict